# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import List
from typing_extensions import TypeAlias

from .identity import Identity

__all__ = ["IdentityListResponse"]

IdentityListResponse: TypeAlias = List[Identity]
