# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import List
from typing_extensions import TypeAlias

from .archive import Archive

__all__ = ["ArchiveListResponse"]

ArchiveListResponse: TypeAlias = List[Archive]
